pub struct OfficeConvertLambda { /* private fields */ }Implementations
Sourceimpl OfficeConvertLambda
impl OfficeConvertLambda
pub fn new(client: Client, options: OfficeConvertLambdaOptions) -> Self
Sourceimpl OfficeConvertLambda
impl OfficeConvertLambda
Sourcepub async fn convert(&self, request: ConvertRequest) -> Result<(), ConvertError>
pub async fn convert(&self, request: ConvertRequest) -> Result<(), ConvertError>
Perform an invoke of the convert lambda using a ConvertRequest based on files already present in S3
Will attempt to retry on failure based on the current options